<?php


namespace FiloBlu\PaymentMethodFilter\Observer\Payment;

class MethodIsActive implements \Magento\Framework\Event\ObserverInterface
{

    protected $helper;

    public function __construct(
        \FiloBlu\PaymentMethodFilter\Helper\PaymentFilter $helper) {
        $this->helper = $helper;
    }

    /**
     * Execute observer
     *
     * @param \Magento\Framework\Event\Observer $observer
     * @return void
     */
    public function execute(
        \Magento\Framework\Event\Observer $observer
    ) {
        $result = $observer->getData('result');
        $method_instance = $observer->getData('method_instance');
        $quote = $observer->getData('quote');

        if ($this->helper->isFilterEnabled() == FALSE) {
            return;
        }

        $paymentMethodWhitelist = $this->helper->paymentMethodWhitelist();
        if (empty($paymentMethodWhitelist)) {
            return;
        }

        $filterConditions = $this->helper->getFilterconditions();
        if (empty($filterConditions)) {
            if ($this->checkMethodAgainstWhitelist($method_instance->getCode(), $paymentMethodWhitelist)) {
                return;
            } else {
                $result->setData('is_available', FALSE);
            }
        }

        //NB: $result may be filtered multiple times if conditions are multiple (when implemented)
        foreach ($filterConditions as $condition) {
            switch ($condition) {
                case 'giftcard':
                    if ($this->helper->quoteContainsGiftcard($quote) && $this->checkMethodAgainstWhitelist($method_instance->getCode(), $paymentMethodWhitelist) == FALSE) {
                        $result->setData('is_available', FALSE);
                    }
                    break;
                case '*': //"any"
                    if ($this->checkMethodAgainstWhitelist($method_instance->getCode(), $paymentMethodWhitelist) == FALSE) {
                        $result->setData('is_available', FALSE);
                    }
                case '':
                default:
                    break;
            }
        }
    }

    protected function checkMethodAgainstWhitelist($methodCode, $paymentMethodWhitelist) {
         return in_array($methodCode, $paymentMethodWhitelist);
    }
}